<?php
/*
 * timeline.js.php
 * Description: JavaScript for the SIMILE Timline Plugin
 * Plugin URI: http://www.freshlabs.de/journal/archives/2006/10/wordpress-plugin-simile-timeline/
 * Author: Tim Isenheim
 * 
	===========================================================================
	SIMILE Timeline for WordPress
	Copyright (C) 2006 Tim Isenheim
	
	This program is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
	===========================================================================
*/
include_once('../../../../wp-blog-header.php');
include_once('../inc/timeline-js.inc.php');
// hardcoded HTTP header 200
define('WP_USE_THEMES', false) ;
header("HTTP/1.1 200 OK");
header("Status: 200 All rosy");

// Create JavaScript file header
header("Cache-Control: public");
header("Pragma: cache");

$offset = 60*60*24*10; // 10 days
header("Expires: ".gmdate("D, d M Y H:i:s",time() + $offset)." GMT");
header("Last-Modified: ".gmdate("D, d M Y H:i:s",filemtime(__FILE__))." GMT");
header("Content-Type: text/javascript; charset: UTF-8");
// ===========================================================================

// Timeline orientation, vertical timelines still don't work
if(get_option('stl_timeline_orientation')){
	$orientation = get_option('stl_timeline_orientation');	
} else $orientation = 0;

// get Timeline configurations
$stl_startdate_id = get_option('stl_timeline_startdate');

// Start and end date (scroll boundaries)
$stl_timeline_start = 0;
$stl_timeline_stop = 0;

// default category and DOM-Id
$categories = '1';
$domid = "stl-mytimeline";

if(get_option('stl_timeline_usestartstop')==1){
	$stl_timeline_start = get_option('stl_timeline_start');
	$stl_timeline_stop = get_option('stl_timeline_stop');
}
else{
	$stl_timeline_start = $_GET['start'];
	$stl_timeline_stop = $_GET['stop'];
}

if(isset($_GET['cat'])){
	// only allow comma seperated category IDs
	$categories = preg_replace('/[^0-9.,]/','', $_GET['cat']);
	$categories = esc_js($categories);
}

// Get ID of timeline div
if(isset($_GET['id'])){
	$domid=preg_replace('/[^a-z0-9.\-_]/','', $_GET['id']);
	$domid = esc_js($domid);
}

?>
/* WP SIMILE Timeline JavaScript configuration script
 * Plugin version: <?php echo get_option('stl_timeline_plugin_version'); ?>
 */
var tl;
function loadSimileTimeline() {
	
	if(document.getElementById("<?php echo $domid; ?>")){	
		
		// ### create custom theme
<?php stl_api_createTheme(''.
				'label_width=200&'.
				'bubble_width=320&'.
				'bubble_height=300&'.
				'timeline_start='.$stl_timeline_start.'&'.
				'timeline_stop='.$stl_timeline_stop.''.
''); ?>

var eventSource = new Timeline.DefaultEventSource();
<?php
$datafile = STL_TIMELINE_DATA_FOLDER.'/timeline.xml.php';
#stl_api_createEventSourceArray($datafile, $categories);
// load data / event source
stl_api_createEventSource($datafile, $categories, 'eventSource');
?>

<?php
$stl_startdate = null;

// Evaluate the timeline start date (Where to focus on load)
switch($stl_startdate_id){
	case 3:		// In the middle of all events
		$a1= WPSimileTimelineToolbox::myGetDate(WPSimileTimelineDatabase::getMinMaxEventDate('MAX','end', null, $categories));
		$b1= WPSimileTimelineToolbox::myGetDate(WPSimileTimelineDatabase::getMinMaxEventDate('MIN','start', null, $categories));
		// calculate arithmetic middle date
		$amd = adodb_mktime(
			($a1['hour'] + $b1['hour'])/2,
			($a1['minute'] + $b1['minute'])/2,
			($a1['second'] + $b1['second'])/2,
			($a1['month'] + $b1['month'])/2,
			($a1['day'] + $b1['day'])/2,
			($a1['year'] + $b1['year'])/2
		);
		$stl_startdate = adodb_date('r', $amd);
		break;
	case 2:		// at end date of last post
		$stl_startdate = WPSimileTimelineDatabase::getMinMaxEventDate('MAX','end', 'r', $categories);
		break;
	case 1:		// at start date of first post
		$stl_startdate = WPSimileTimelineDatabase::getMinMaxEventDate('MIN','start', 'r', $categories);
		break;
	case 0:  // at current date
		$stl_startdate = date('r');
		break;
	default: // in case a custom date is set (TODO: implement)
		$stl_startdate = adodb_date('r', strtotime($stl_startdate_id));
}

// request all Timeline Band objects
$stl_timeline_band = new WPSimileTimelineBand();
$stl_bands = $stl_timeline_band->find_all();
$useCompactPainter = get_option('stl_timeline_useattachments') == 1 ? true : false;
// Build timeline band infos
$i=0;
echo 'var bandInfos = [';
foreach($stl_bands as $band){
	$hotzones = '';
	
	foreach($band->hotzones as $hotzone){
		$hotzones .= stl_api_createZone($stl_timeline_resolutions[$hotzone->unit], adodb_date2('r',$hotzone->start_date), adodb_date2('r',$hotzone->end_date), $hotzone->magnify, $hotzone->multiple);
		if($i<sizeof($hotzones)-1) $hotzones .= ',';
	}
	
	stl_api_createBandInfo(
				$hotzones,
				$band->height,
				$stl_timeline_resolutions[$band->unit],
				$band->interval_size,
				'mytheme',
				($band->show_labels == 1 ? 'true' : 'false'),
				"eventSource",
				$useCompactPainter,
				$stl_startdate,
				"0",
				'0.5',
				'0.3',
				'de'
	);
	if($i<sizeof($stl_bands)-1) echo ',';
	$i++;
}
echo '];';

// Sync all timeline bands (has to be done manually)
?>
for(var i=1;i < bandInfos.length;i++){
	bandInfos[i].syncWith = 0;   // synchronize with primary band
	bandInfos[i].highlight = true;   // highlight focused area
	//bandInfos[i].eventPainter.setLayout(bandInfos[0].eventPainter.getLayout());
}
<?php
// Build Highlight decorators
$b=0; // band index
$stl_timeline_decorator = new WPSimileTimelineDecorator();
foreach($stl_bands as $band){
	$k=0; // decorator index
	$decorators = '';
	if(!empty($band->decorators)){
		$s = sizeof($band->decorators)-1;
		echo 'bandInfos['.$b.'].decorators = [';
		$decorator_types = $stl_timeline_decorator->get_types();
		foreach($band->decorators as $decorator){
			echo stl_api_createHighlightDecorator(
				$decorator_types[$decorator->type],
				adodb_date2('r',$decorator->start_date),
				adodb_date2('r',$decorator->end_date),
				$decorator->start_label,
				$decorator->end_label,
				$decorator->color,
				$decorator->css_class,
				$decorator->opacity
			);
			if($k<$s) echo ',';
			$k++;
		}
		$b++;
		echo '];' . "\n";
	}
}

// create actual timeline object
	stl_api_createTimeLine($domid, 'bandInfos', $orientation);
	
	// change click event for timeline entries
	if(get_option('stl_timeline_linkhandling')){
		echo 'Timeline.OriginalEventPainter.prototype._showBubble = function(x,y,evt){';
		echo 'document.location.href=evt.getLink();';
		echo '}';
	}
?>
  }else{ /* empty - do nothing when no timeline-frame is found */ }
}


/*
 * Static functions and onload handler for the actual init process
 */
var resizeTimerID = null;
function resizeSimileTimeline() {
    if (resizeTimerID == null) {
        resizeTimerID = window.setTimeout(function() {
            resizeTimerID = null;
            tl.layout();
        }, 500);
    }
}

/* addEvent function - by Scott Andrew 
 * http://www.scottandrew.com/weblog/articles/cbs-events
 */
function addEvent(obj, evType, fn){ 
	if (obj.addEventListener){ 
		obj.addEventListener(evType, fn, false); 
		return true; 
	} else if (obj.attachEvent){ 
		var r = obj.attachEvent("on"+evType, fn); 
		return r; 
	} else { 
		return false; 
	} 
}

// load Timeline on window load
addEvent(window, "load", loadSimileTimeline);
addEvent(window, "resize", resizeSimileTimeline);